==> openjdk-14_14.0.2+12.orig.tar.xz: openjdk-14-14.0.2+12/test/hotspot/jtreg/runtime/cds/appcds/sharedStrings/SharedStringsBasic.java <==
/*
 * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

/*
 * @test
 * @summary Basic test for shared strings
 * @requires vm.cds.archived.java.heap
 * @library /test/hotspot/jtreg/runtime/cds/appcds /test/lib
 * @modules jdk.jartool/sun.tools.jar
 * @build HelloString
 * @run driver SharedStringsBasic
 */
import jdk.test.lib.process.OutputAnalyzer;
import jdk.test.lib.process.ProcessTools;

// This test does not use SharedStringsUtils.dumpXXX()
// and SharedStringsUtils.runWithXXX() intentionally:
// - in order to demonstrate the basic use of the functionality
// - to provide sanity check and catch potential problems in the utils
public class SharedStringsBasic {
    public static void main(String[] args) throws Exception {
        SharedStringsUtils.run(args, SharedStringsBasic::test);
    }

    public static void test(String[] args) throws Exception {
        String vmOptionsPrefix[] = SharedStringsUtils.getChildVMOptionsPrefix();

        String appJar = JarBuilder.build("SharedStringsBasic", "HelloString");

        String sharedArchiveConfigFile =
            TestCommon.getSourceFile("SharedStringsBasic.txt").toString();

        ProcessBuilder dumpPb = ProcessTools.createJavaProcessBuilder(true,
          TestCommon.concat(vmOptionsPrefix,
            "-cp", appJar,
            "-XX:SharedArchiveConfigFile=" + sharedArchiveConfigFile,
            "-XX:SharedArchiveFile=./SharedStringsBasic.jsa",
            "-Xshare:dump",
            "-Xlog:cds,cds+hashtables"));

        TestCommon.executeAndLog(dumpPb, "dump")
            .shouldContain("Shared string table stats")
            .shouldHaveExitValue(0);

        ProcessBuilder runPb = ProcessTools.createJavaProcessBuilder(true,
          TestCommon.concat(vmOptionsPrefix,
            "-cp", appJar,
            "-XX:SharedArchiveFile=./SharedStringsBasic.jsa",
            "-Xshare:auto",
            "-showversion",
            "HelloString"));

        TestCommon.executeAndLog(runPb, "run").shouldHaveExitValue(0);
    }
}

==> openjdk-16_16.0.1+9.orig.tar.xz: openjdk-16-16.0.1+9/test/hotspot/jtreg/runtime/cds/appcds/sharedStrings/SharedStringsBasic.java <==
/*
 * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

/*
 * @test
 * @summary Basic test for shared strings
 * @requires vm.cds.archived.java.heap
 * @library /test/hotspot/jtreg/runtime/cds/appcds /test/lib
 * @build HelloString
 * @run driver SharedStringsBasic
 */
import jdk.test.lib.process.OutputAnalyzer;
import jdk.test.lib.process.ProcessTools;

// This test does not use SharedStringsUtils.dumpXXX()
// and SharedStringsUtils.runWithXXX() intentionally:
// - in order to demonstrate the basic use of the functionality
// - to provide sanity check and catch potential problems in the utils
public class SharedStringsBasic {
    public static void main(String[] args) throws Exception {
        SharedStringsUtils.run(args, SharedStringsBasic::test);
    }

    public static void test(String[] args) throws Exception {
        String vmOptionsPrefix[] = SharedStringsUtils.getChildVMOptionsPrefix();

        String appJar = JarBuilder.build("SharedStringsBasic", "HelloString");

        String sharedArchiveConfigFile =
            TestCommon.getSourceFile("SharedStringsBasic.txt").toString();

        ProcessBuilder dumpPb = ProcessTools.createTestJvm(
          TestCommon.concat(vmOptionsPrefix,
            "-cp", appJar,
            "-XX:SharedArchiveConfigFile=" + sharedArchiveConfigFile,
            "-XX:SharedArchiveFile=./SharedStringsBasic.jsa",
            "-Xshare:dump",
            "-Xlog:cds,cds+hashtables"));

        TestCommon.executeAndLog(dumpPb, "dump")
            .shouldContain("Shared string table stats")
            .shouldHaveExitValue(0);

        ProcessBuilder runPb = ProcessTools.createTestJvm(
          TestCommon.concat(vmOptionsPrefix,
            "-cp", appJar,
            "-XX:SharedArchiveFile=./SharedStringsBasic.jsa",
            "-Xshare:auto",
            "-showversion",
            "HelloString"));

        TestCommon.executeAndLog(runPb, "run").shouldHaveExitValue(0);
    }
}
